@@ -2,6 +2,7 @@ import type { QueryClient } from "@tanstack/react-query";
 import { createRootRouteWithContext, Outlet } from "@tanstack/react-router";
 import { getSettings } from "@/api";
 import { useQuery } from "@tanstack/react-query";
+import { useCloudStatus } from "@/hooks/useCloudStatus";
 
 function RootComponent() {
   // This hook ensures settings are fetched on app startup
@@ -9,6 +10,8 @@ function RootComponent() {
     queryKey: ["settings"],
     queryFn: getSettings,
   });
+  // Fetch cloud status on startup (best-effort)
+  useCloudStatus();
 
   return (
     <div>
